import React from 'react'
import { Row, Col, Form, Input, InputNumber, Radio, notification, Select } from 'antd'
import FileUpload from '@/components/XForm/FileUpload';
import ImageUpload from '@/components/XForm/ImageUpload';
import ImageListUpload from '@/components/XForm/ImageListUpload';
import SelectCity from '@/components/SelectButton/CitySelect'
import AreaSelect from '@/components/SelectButton/AreaSelect'
import BuildingType from './components/BuildingTypeSelect'
import OpenTimePicker from './components/OpenTimePicker'
import Amap from './components/Amap'
import { formItemLayout, groupItemLayout } from './utils'

const fullWidth= { width: '100%' }

const Item = Form.Item

const GroupItem = ({children}) => (
  <Row gutter={24}>
    <Col span={12}>{children[0]}</Col>
    <Col span={11}>{children[1]}</Col>
  </Row>
)

const BuildingBasic = (props) => {
  const { form } = props;
  const { getFieldDecorator, getFieldValue, setFieldsValue } = form;

  
  // 视频文件上传前 回调
  const fileUploadBeforeUpload = (file, fileList) => {
    return new Promise((resolve, reject) => {
      if (file.type === 'video/mp4' || file.type === '.mp4') {
          // setVideoImage(true)
          resolve(file)
      } else {
        notification.error({ message: '项目视频，仅支持MP4格式' })
        reject()
      }
    })
  }

  // 周边设施 回调
  function handleMapScope(e) {
    const coordinateValue = getFieldValue('coordinate')
    if (!coordinateValue) {
      notification.error({ message: '请先选择项目坐标位置' })
      return
    }

    const lngLat = getFieldValue('coordinate').split(',')
    const poiData = [].concat(POI_TYPES)
    poiData.map(item => {
      getAroundData({ types: item.key, location: lngLat, radius: e }).then(res => {
        const { pois } = res
        setFormMapScopeValue(item.key, pois)
      }).catch(err => {
        console.error(err)
        notification.error({ message: '周边数据获取失败' })
      })
    })
  }

  return (
    <Form {...formItemLayout}>
      <Item label="项目Id" style={{ display: 'none' }}>
        {getFieldDecorator('buildingId')(<Input disabled />)}
      </Item>
      {/* <Item label="楼盘编号" >
        {getFieldDecorator('code', {
          rules: [{ required: true, message: '请输入楼盘编号' }],
        })(<Input />)}
      </Item> */}
      <Item label="楼盘名称" >
        {getFieldDecorator('buildingName', {
          rules: [{ required: true, message: '请输入楼盘名' }],
        })(<Input />)}
      </Item>
      <Form.Item label="项目类型">
        {getFieldDecorator('buildingProjectType', {
          rules: [{ required: true, message: '请选择项目类型' }],
        })(<BuildingType />)}
      </Form.Item>
      <Form.Item label="列表均价" help="项目列表展示价格，示例：约10000元/㎡、约1000万元/套起">
        {getFieldDecorator('price')(<Input />)}
      </Form.Item>
      <GroupItem>
        <Form.Item label="开盘时间" {...groupItemLayout.a} >
          {getFieldDecorator('openingDate')(
            <OpenTimePicker placeholder="请选择开盘时间" style={fullWidth} />
          )}
        </Form.Item>
        <Form.Item label="电话" {...groupItemLayout.b } >
          {getFieldDecorator('tel', {
            rules: [
              {
                pattern: new RegExp('^[0-9]*$'),
                message: '请输入正确的电话号码',
              },
            ],
          })(<Input placeholder="手机或者座机号码" />)}
        </Form.Item>
      </GroupItem>
      <Form.Item label="项目说明" >
        {getFieldDecorator('dynamic')(<Input placeholder="项目动态等，不超过30个字" maxLength={30}/>)}
      </Form.Item>
      {/* <Form.Item label="物业类型" >
        {getFieldDecorator('propertyType')(<Input />)}
      </Form.Item> */}
      <Form.Item label="销售状态" >
        {getFieldDecorator('marketStatus', {
          rules: [{ required: true, message: '请选择销售状态' }],
        })(
          <Select placeholder="销售状态" style={fullWidth}>
            <Select.Option value="待售">待售</Select.Option>
            <Select.Option value="在售">在售</Select.Option>
            <Select.Option value="售罄">售罄</Select.Option>
            <Select.Option value="在租">在租</Select.Option>
          </Select>,
        )}
      </Form.Item>
      <Form.Item label="项目标签" >
        {getFieldDecorator('tag')(
          <Select mode="tags" placeholder="输入后选中" style={fullWidth} />
        )}
      </Form.Item>

      <GroupItem>
        <Form.Item label="项目视频" help="视频仅支持mp4格式，建议尺寸：750*600，比例5:4，用于楼盘详情" {...groupItemLayout.a} >
          {getFieldDecorator('videoUrl')(
            <FileUpload accept=".mp4" beforeUpload={fileUploadBeforeUpload} label="上传视频" size={1} />,
          )}
        </Form.Item>
        <Form.Item label="视频封面图" help="建议图片尺寸：750*600px，比例5:4,格式：jpg，用于视频封面" labelCol={{span: 8}} wrapperCol={{span:16}}>
          {getFieldDecorator('videoImage', {
            rules: [{ required: true, message: '请选择视频封面图' }],
          })(
            <ImageUpload />,
          )}
        </Form.Item>
      </GroupItem>
      <Form.Item label="楼盘主图" help="建议图片尺寸：750*600px，比例5:4,格式：jpg，用于楼盘详情">
        {getFieldDecorator('avatarImage', {
          rules: [{ required: true, message: '请选择项目主图' }],
        })(
          <ImageListUpload unlimited />,
        )}
      </Form.Item>
      <Form.Item label="楼盘封面图" help="建议图片尺寸：750*420px，比例16:9,格式：jpg，用于楼盘列表">
        {getFieldDecorator('listImage', {
          rules: [{ required: true, message: '请选择列表图' }],
        })(
          <ImageUpload />,
        )}
      </Form.Item>
      <GroupItem>
        <Form.Item label="首页推荐" {...groupItemLayout.a} >
          {getFieldDecorator('isMain', { initialValue: 1 })(
            <Radio.Group>
              <Radio value={1}>是</Radio>
              <Radio value={2}>否</Radio>
            </Radio.Group>,
          )}
        </Form.Item>
        <Form.Item label="排序" help="数值越大，楼盘在小程序列表页中展示越靠前" {...groupItemLayout.b}>
          {getFieldDecorator('orderNo')(<InputNumber min={0} style={fullWidth} />)}
        </Form.Item>
      </GroupItem>
      <GroupItem>
        <Form.Item label="所在城市" {...groupItemLayout.a } >
          {getFieldDecorator('cityId', {
            rules: [{ required: true, message: '请选择城市' }],
          })(
            <SelectCity style={fullWidth} />,
          )}
        </Form.Item>
        <Form.Item label="楼盘区域" {...groupItemLayout.b } >
          {getFieldDecorator('buildingArea', {
            rules: [{ required: true, message: '请输入楼盘区域' }],
          })(<AreaSelect style={fullWidth} />)}
        </Form.Item>
      </GroupItem>
      <Form.Item label="项目地址" >
        {getFieldDecorator('address', {
          rules: [{ required: true, message: '请输入项目地址' }],
        })(<Input />)}
      </Form.Item>
      <Form.Item label="地图位置" >
        {getFieldDecorator('mapCoordinate')(<Amap onChange={e => setFieldsValue({ coordinate: e })}/>)}
      </Form.Item>
      <GroupItem>
        <Form.Item label="项目坐标" {...groupItemLayout.a } >
          {getFieldDecorator('coordinate', {
            rules: [{ required: true, message: '请输入项目坐标' }],
          })(<Input disabled />)}
        </Form.Item>
        <Form.Item label="周边范围" {...groupItemLayout.b } >
          {getFieldDecorator('mapScope', {
            rules: [{ required: true, message: '请选择周边设施搜索范围' }],
          })(
            <Select placeholder="周边设施搜索范围" style={fullWidth} onChange={e => getMapScope(e)}>
              <Option value={1000}>1公里</Option>
              <Option value={3000}>3公里</Option>
              <Option value={5000}>5公里</Option>
              <Option value={10000}>10公里</Option>
            </Select>,
          )}
        </Form.Item>
      </GroupItem>

    </Form>
  )
}

export default Form.create({ onValuesChange: console.log })(BuildingBasic)
