import React, { useEffect, useRef, useState } from 'react'
import { Typography, Tag, Input } from 'antd'

export default React.forwardRef((props, ref) => {
  const inputRef = useRef()
  const valRef = useRef()
  const [inputValue, setInputValue] = useState()
  const [inputVisible, setInputVisible] = useState(false)
  const [tags, setTags] = useState([])
  // 地图周边 tag
  const [mapTags, setMapTags] = useState([])

  const handleClose = (tag) => {
    if (mapTags.indexOf(tag) > -1) {
      setMapTags(mapTags.filter((t) => t !== tag))
    }

    if (props.onChange) {
      props.onChange(tags.filter((t) => t !== tag).join(','))
    }
  }

  const handleInputConfirm = () => {
    const exists = tags.indexOf(inputValue) > -1
    if (!exists) {
      props.onChange(tags.concat(inputValue).join(','))
    }
    setInputVisible(false)
    setInputValue()
  }

  useEffect(() => {
    setMapTags(props.mapPois || [])
  }, [props.mapPois])

  useEffect(() => {
    const vals = (props.value||'').split(',')
    const arr = vals.concat(mapTags)

    // 去重
    const nwTags = []
    arr.forEach((it) => {
      if (nwTags.indexOf(it) === -1) {
        nwTags.push(it)
      }
    })

    setTags(nwTags)
  }, [props.value, mapTags])

  return (
    <div>
      {
        tags.map((tag) => (
          <Tag key={tag} closable onClose={() => handleClose(tag)}>
            <Typography.Text>{tag}</Typography.Text>
          </Tag>
        ))
      }
      {
        inputVisible ? (
          <Input
            ref={inputRef}
            type="text"
            size="small"
            style={{ width: 80, display: inputVisible ? 'block' : 'none' }}
            value={inputValue}
            onChange={e => setInputValue(e.target.value)}
            onBlur={handleInputConfirm}
            onPressEnter={handleInputConfirm}
          />
        ) : (
          <Tag onClick={() => setInputVisible(true)} style={{ background: '#fff', borderStyle: 'dashed' }}>
            <Icon type="plus" /> 新建
          </Tag>
        )
      }
    </div>
  )
})
